pub struct TextInput { /* private fields */ }Expand description
A single-line text input widget with cursor and editing support.
Implementations
Sourceimpl TextInput
impl TextInput
Sourcepub const fn with_config(bounds: Rect, config: TextInputConfig) -> Self
pub const fn with_config(bounds: Rect, config: TextInputConfig) -> Self
Create a new text input widget with custom configuration.
Sourcepub fn set_content(&mut self, content: &str)
pub fn set_content(&mut self, content: &str)
Set the content, moving cursor to end.
Sourcepub const fn set_focused(&mut self, focused: bool)
pub const fn set_focused(&mut self, focused: bool)
Set focus state.
Sourcepub const fn is_focused(&self) -> bool
pub const fn is_focused(&self) -> bool
Check if focused.